plimit(1) 맨 페이지 - 윈디하나의 솔라나라

개요

섹션
맨 페이지 이름
검색(S)

plimit(1)

plimit(1)                        User Commands                       plimit(1)

NAME
       plimit - get or set the resource limits of running processes

SYNOPSIS
       plimit [-hkm] [--scale[=item1,,item2,...]] pid...


       plimit {-cdfnstv [soft][,hard]}... pid...

DESCRIPTION
       If  one  or  more  of the cdfnstv options is specified, plimit sets the
       soft (current) limit and/or the hard (maximum) limit of  the  indicated
       resource(s)  in  the  processes identified by the process-ID list, pid.
       Otherwise plimit reports the resource limits of the  processes  identi‐
       fied by the process-ID list, pid.


       The  owner  of a process is permitted to either get or set the resource
       limits of a process, unless the process has  the  {PRIV_PROC_SENSITIVE}
       flag  set (see the getpflags(2) man page). The {PRIV_PROC_OWNER} privi‐
       lege is required to get or set the resource limits of a  process  which
       is  either  owned  by another uid or has the {PRIV_PROC_SENSITIVE} flag
       set. The {PRIV_SYS_RESOURCE} privilege is required to increase  a  hard
       limit.

OPTIONS
       The following options are supported:

       -h

           On  output,  file  and  memory sizes are scaled to a human readable
           format. The -h option is equivalent to using  the  --scale=max,1024
           option.


       -k

           On output, show file sizes in kilobytes (1024 bytes) rather than in
           512-byte blocks.


       -m

           On  output,  show  file  and  memory  sizes in megabytes (1024*1024
           bytes).


       --scale[=item1,item2,...]

           On output, file and memory sizes are scaled  to  a  human  readable
           format,  for  example, 14K, 234M, 2.7G, or 3.0T. Scaling is done by
           repetitively dividing by 1024, unless otherwise specified.  --scale
           specified  without  arguments enables default scaled output, and is
           equivalent to --scale=max,1024. See scale(7)  for  a  complete  de‐
           scription of --scale features.


       -?
       --help

           Print usage message and immediately exit.




       The remainder of the options are used to change specified resource lim‐
       its. They each accept an argument of the form:


       soft,hard


       where  soft  specifies  the soft (current) limit and hard specifies the
       hard (maximum) limit. If the hard limit is not specified, the comma may
       be omitted. If the soft limit is an empty string, only the  hard  limit
       is set. Each limit can have one of the following forms:

       unlimited       The  literal  string  unlimited indicates that no limit
                       applies to the given resource.


       n[.n][scale]    A plain number, with an  optional  fraction  and  scale
                       factor. When specifying CPU time, the h or m scale fac‐
                       tors  can  be  applied, indicating hours or minutes re‐
                       spectively. When specifying file or memory  sizes,  the
                       k,  m,  g,  t, p, and e scale factors can be specified,
                       denoting kilobytes,  megabytes,  gigabytes,  terabytes,
                       petabytes, or exabytes, respectively.


       mm:ss           Minutes and seconds (for CPU time only).



       The soft limit cannot exceed the hard limit.

       -c soft,hard    Set  core  file  size  limits (default unit is 512-byte
                       blocks).


       -d soft,hard    Set data segment (heap) size limits  (default  unit  is
                       kilobytes).


       -f soft,hard    Set file size limits (default unit is 512-byte blocks).


       -n soft,hard    Set file descriptor limits (no default unit).


       -s soft,hard    Set  stack  segment  size limits (default unit is kilo‐
                       bytes).


       -t soft,hard    Set CPU time limits (default unit is seconds).


       -v soft,hard    Set virtual memory size limits (default unit  is  kilo‐
                       bytes).


OPERANDS
       The following operands are supported.

       pid    Process ID list. May be specified as a numeric id or /proc/pid.


EXAMPLES
       Example 1 Setting a limit for a single process



       The  following  example sets the file descriptor soft limit to 1024 and
       does not change the hard limit, for process id 5114:


         $ plimit -n 1024 5114




       Note that some programs do not check if the number of file  descriptors
       they  can  use has changed while running and may continue to use to the
       number they had at startup.

       Example 2 Setting a limit for all running processes



       The following example sets the maximum core dump size  (both  soft  and
       hard limits) to zero bytes for all processes running on the system:


         # plimit -c 0,0 /proc/*


EXIT STATUS
       plimit  returns  the  exit  value  zero on success, non-zero on failure
       (such as no such process, permission denied, or invalid option).

FILES
       /proc/pid/*    process information and control files


ATTRIBUTES
       See attributes(7) for descriptions of the following attributes:

       tab() box; cw(2.75i) |cw(2.75i) lw(2.75i) |lw(2.75i) ATTRIBUTE  TYPEAT‐
       TRIBUTE VALUE _ Availabilitysystem/core-os


SEE ALSO
       prctl(1), proc(1), ulimit(1), getpflags(2), getrlimit(2), setrlimit(2),
       proc(5), attributes(7), privileges(7), scale(7)

HISTORY
       The  -?,  -h,  --help, and --scale options were added in Oracle Solaris
       11.4.42.


       The plimit command was added in Solaris 7.

Oracle Solaris 11.4               29 Nov 2022                        plimit(1)
맨 페이지 내용의 저작권은 맨 페이지 작성자에게 있습니다.
RSS ATOM XHTML 5 CSS3